@@ -12,6 +12,7 @@ class ConfigModel(Config):
         self._gcp_project_id: str = None
         self._model_name: str = None
         self._model_version: str = None
+        self._split_log_debug: str = None
 
         # flags
         self._refresh_rate: int = None
@@ -39,6 +40,12 @@ class ConfigModel(Config):
                     raise Exception(f'Config file is missing the algo version or version is not an integer. '
                                     f'Check your config.yaml')
 
+                self._split_log_debug = Config.get_key('split_log_debug', self._mc)
+                if self._split_log_debug is None or not isinstance(self._split_log_debug, bool):
+                    print("Missing split_log_debug paramer in the config file. Defaulting to only keep one version" +
+                          " of logs.")
+                    self._split_log_debug = False
+
                 self._features = Config.get_key('features', self._mc)
                 self._model_output = Config.get_key('model_output', self._mc)
                 ConfigModel._validate_features(self._features)
@@ -89,6 +96,10 @@ class ConfigModel(Config):
     def get_model_version(self) -> str:
         return self._model_version
 
+    @_load_main
+    def get_split_log_debug(self) -> bool:
+        return self._split_log_debug
+
     @_load_main
     def get_features(self) -> dict:
         return self._features
