@@ -54,8 +54,7 @@ class FeatureStore:
         # sending the request. Please make sure the payload is a valid json string
         r = requests.get(url=f"{FeatureStore.HOST}/kinds/{view}/{id}",
                          headers=receiving_service_headers,
-                         verify=False,
-                         timeout=1
+                         verify=False
                          )
         r.encoding = 'utf-8'
         if r.status_code == 401:
@@ -74,8 +73,7 @@ class FeatureStore:
         r = requests.post(url=f"{FeatureStore.HOST}/kinds/{view}",
                           data=json.dumps({"ids": ids}),
                           headers=receiving_service_headers,
-                          verify=False,
-                          timeout=1)
+                          verify=False)
         r.encoding = 'utf-8'
         if r.status_code == 401:
             raise Exception("service account does not have access to the FeatureStore")
